@@ -3,7 +3,7 @@ import unicodedata
 import attr
 from clldutils.misc import nfilter, lazyproperty
 
-from pyclts.util import norm
+from pyclts.util import norm, jaccard
 
 __all__ = [
     'is_valid_sound',
@@ -20,17 +20,17 @@ EXCLUDE_FEATURES = [
     'apical',
     'laminal',
     'ejective',
-    'with_falling_tone',
-    'with_extra-low_tone',
-    'with_extra-high_tone',
-    'with_falling_tone',
-    'with_low_tone',
-    'with_global_fall',
-    'with_global_rise',
-    'with_high_tone',
-    'with_mid_tone',
-    'with_rising_tone',
-    'with_upstep'
+    'with-falling_tone',
+    'with-extra-low_tone',
+    'with-extra-high_tone',
+    'with-falling_tone',
+    'with-low_tone',
+    'with-global_fall',
+    'with-global_rise',
+    'with-high_tone',
+    'with-mid_tone',
+    'with-rising_tone',
+    'with-upstep'
 ]
 # Disable cmp in a backwards and forwards compatible way:
 cmp_off = {"eq" if getattr(attr, "__version_info__", (0,)) >= (19, 2) else "cmp": False}
@@ -137,8 +137,7 @@ class Sound(Symbol):
         return frozenset(self._features() + [self.type])
 
     def similarity(self, other):
-        f1, f2 = self.featureset, other.featureset
-        return len(f1.intersection(f2)) / len(f1.union(f2))
+        return jaccard(self.featureset, other.featureset)
 
     def __str__(self):
         """
@@ -215,6 +214,12 @@ class Sound(Symbol):
                 tbl += [','.join(bundle)]
         return tbl
 
+    @property
+    def symbols(self):
+        """Returns all unicode sounds separated by the empty sound marker.
+        """
+        return ' '.join(['◌' + s for s in self.s])
+
 
 @attr.s(**cmp_off)
 class Marker(Symbol):
@@ -255,12 +260,13 @@ class Consonant(Sound):
     voicing = attr.ib(default=None)
     breathiness = attr.ib(default=None)
     creakiness = attr.ib(default=None)
-    sibilancy = attr.ib(default=None)
-    laterality = attr.ib(default=None)
+    airstream = attr.ib(default=None)
     laminality = attr.ib(default=None)
     articulation = attr.ib(default=None)
     raising = attr.ib(default=None)
     relative_articulation = attr.ib(default=None)
+    friction = attr.ib(default=None)
+    tongue_root = attr.ib(default=None)
 
     # write order determines how consonants are written according to their
     # features, so this normalizes the order of diacritics preceding and
@@ -268,19 +274,57 @@ class Consonant(Sound):
     _write_order = dict(
         pre=['preceding'],
         post=[
-            'raising', 'relative_articulation',
-            'laminality', 'creakiness', 'phonation', 'ejection', 'syllabicity', 'voicing',
+            'raising',
+            'relative_articulation',
+            'laminality',
+            'creakiness',
+            'tongue_root',
+            'phonation',
+            'ejection',
+            'syllabicity',
+            'voicing',
             'articulation',
-            'nasalization', 'palatalization', 'labialization',
-            'breathiness', 'aspiration', 'glottalization', 'velarization',
-            'pharyngealization', 'release', 'duration'])
+            'nasalization',
+            'release',
+            'palatalization',
+            'labialization',
+            'velarization',
+            'pharyngealization',
+            'glottalization',
+            'breathiness',
+            'aspiration',
+            'friction',
+            'duration',
+        ],
+    )
+
     _name_order = [
-        'raising', 'relative_articulation',
-        'articulation', 'preceding', 'syllabicity', 'nasalization', 'palatalization',
-        'labialization', 'glottalization', 'aspiration', 'velarization',
-        'pharyngealization', 'duration', 'release', 'voicing', 'creakiness',
-        'breathiness', 'phonation', 'laminality', 'place', 'ejection', 'laterality',
-        'sibilancy', 'manner']
+        'raising',
+        'relative_articulation',
+        'friction',
+        'articulation',
+        'preceding',
+        'syllabicity',
+        'nasalization',
+        'palatalization',
+        'labialization',
+        'velarization',
+        'pharyngealization',
+        'glottalization',
+        'aspiration',
+        'duration',
+        'release',
+        'voicing',
+        'creakiness',
+        'breathiness',
+        'phonation',
+        'laminality',
+        'tongue_root',
+        'place',
+        'ejection',
+        'airstream',
+        'manner',
+    ]
 
 
 @attr.s(repr=False, **cmp_off)
@@ -333,7 +377,7 @@ class Vowel(Sound):
     roundedness = attr.ib(default=None)
     height = attr.ib(default=None)
     nasalization = attr.ib(default=None)
-    frication = attr.ib(default=None)
+    friction = attr.ib(default=None)
     duration = attr.ib(default=None)
     voicing = attr.ib(default=None)
     breathiness = attr.ib(default=None)
@@ -356,18 +400,31 @@ class Vowel(Sound):
     _write_order = dict(
         pre=[],
         post=[
-            'tongue_root', 'raising', 'centrality', 'rounding',
-            'voicing', 'breathiness', 'creakiness',
-            'syllabicity', 'nasalization', 'tone', 'articulation', 'rhotacization',
-            'pharyngealization', 'glottalization', 'velarization', 'duration',
-            'frication', 'relative_articulation'])
+            'tongue_root',
+            'raising',
+            'centrality',
+            'rounding',
+            'voicing',
+            'breathiness',
+            'creakiness',
+            'syllabicity',
+            'friction',
+            'relative_articulation',
+            'nasalization',
+            'tone',
+            'articulation',
+            'rhotacization',
+            'pharyngealization',
+            'glottalization',
+            'velarization',
+            'duration'])
     _name_order = [
         'duration', 'rhotacization', 'pharyngealization',
         'glottalization', 'velarization', 'syllabicity',
         'relative_articulation',
         'tongue_root', 'raising', 'rounding',
         'articulation', 'nasalization', 'voicing', 'creakiness',
-        'breathiness', 'roundedness', 'height', 'frication', 'centrality',
+        'breathiness', 'roundedness', 'height', 'friction', 'centrality',
         'tone']
 
 
